============
 To-Do List
============


1.0
===

- Handle character rotations (tspan05)
- Add real life tests
- Clean code and remove useless TODOs


Future
======

- Filters (fe*, filters* and mask*)
- Mixed relative/absolute shorthands for curves in paths
- Markers on shapes
- Clean text rendering (textdecoration*)
